<?php

namespace ACA\WC\Search\Product;

use ACA\WC\Helper\Select;
use ACP\Search\Comparison;
use ACP\Search\Operators;
use ACP\Search\Query\Bindings;
use ACP\Search\Value;

class Visibility extends Comparison {

	/** @var array */
	private $visibility_options;

	public function __construct( $visibility_options ) {
		$operators = new Operators( array(
			Operators::EQ,
		) );

		$this->visibility_options = $visibility_options;

		parent::__construct( $operators );
	}

	protected function create_query_bindings( $operator, Value $value ) {
		$bindings = new Bindings\Post();
		$bindings->tax_query( $this->get_tax_query( $value ) );

		return $bindings;
	}

	public function get_tax_query( Value $value ) {
		switch ( $value->get_value() ) {

			case 'search':
				return array(
					array(
						'taxonomy' => 'product_visibility',
						'field'    => 'slug',
						'terms'    => array( 'exclude-from-search' ),
						'operator' => 'NOT IN',
					),
					array(
						'taxonomy' => 'product_visibility',
						'field'    => 'slug',
						'terms'    => array( 'exclude-from-catalog' ),
						'operator' => 'IN',
					),
				);

			case 'catalog':
				return array(
					array(
						'taxonomy' => 'product_visibility',
						'field'    => 'slug',
						'terms'    => array( 'exclude-from-catalog' ),
						'operator' => 'NOT IN',
					),
					array(
						'taxonomy' => 'product_visibility',
						'field'    => 'slug',
						'terms'    => array( 'exclude-from-search' ),
						'operator' => 'IN',
					),
				);

			case 'visible':
				return array(
					'taxonomy' => 'product_visibility',
					'field'    => 'slug',
					'terms'    => array( 'exclude-from-catalog', 'exclude-from-search' ),
					'operator' => 'NOT IN',
				);

			case 'hidden':
				return array(
					'taxonomy' => 'product_visibility',
					'field'    => 'slug',
					'terms'    => array( 'exclude-from-catalog', 'exclude-from-search' ),
					'operator' => 'AND',
				);
			default:
				return array();
		}
	}

}